==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/lt_LT.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Klaida, skaitant failus iš šio albumo",
    "Aborting preview. Could not find the file" : "Peržiūra nutraukiama. Nepavyko rasti failo",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau yra",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "No compatible server found at {remote}" : "Nerastas joks suderinamas serveris ties {remote}",
    "Invalid server url" : "Neteisingas serverio url adresas",
    "Could not load the description" : "Nepavyko įkelti aprašo",
    "Could not load the description: " : "Nepavyko įkelti aprašo: ",
    "Copyright" : "Autorių teisės",
    "Could not load the copyright notice: " : "Nepavyko įkelti autorių teisių pranešimo: ",
    "Copyright notice" : "Autorių teisių pranešimas",
    "Link to copyright document" : "Nuoroda į autorių teisių dokumentą",
    "This application may not work properly on your browser." : "Ši programa jūsų naršyklėje gali tinkamai neveikti.",
    "For an improved experience, please install one of the following alternatives" : "Geresniam patyrimui, prašome įdiegti vieną iš šių alternatyvų",
    "Your browser is not supported!" : "Jūsų naršyklė nepalaikoma!",
    "please install one of the following alternatives" : "prašome įdiegti vieną iš šių alternatyvų",
    "Album cannot be shown" : "Albumas negali būti parodytas",
    "No media files found" : "Nerasta duomenų peržiūrai",
    "Upload pictures in the Files app to display them here" : "Norėdami matyti paveikslus čia, įkelkite juos į Failų programėlę",
    "Upload new files via drag and drop or by using the [+] button above" : "Įkelkite naujus failus, vilkdami juos čia arba pasinaudoję viršuje esančiu mygtuku [+]",
    "Configuration error" : "Konfigūracijos klaida",
    "Hide Album" : "Slėpti albumą",
    "Could not hide album" : "Nepavyko paslėpti albumo",
    "Error loading slideshow template" : "Klaida, įkeliant skaidrių rodymo šabloną",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Klaida!</strong> Nepavyko sukurti šio failo peržiūros.<br> Prašome pereiti prie kitos skaidrės, kol mes pašalinsime šį paveikslą iš skaidrių rodymo",
    "Next" : "Kitas",
    "Play" : "Groti",
    "Pause" : "Pristabdyti",
    "Previous" : "Ankstesnis",
    "Close" : "Užverti",
    "Download" : "Atsisiųsti",
    "Toggle background" : "Perjungti foną",
    "Delete" : "Ištrinti",
    "Share" : "Bendrinti",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\", kadangi failas tokiu pavadinimu jau yra",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
    "Upload" : "Įkelti",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida bandant pasidalinti",
    "Error while unsharing" : "Klaida bandant nustoti dalintis",
    "Error while changing permissions" : "Klaida keičiant peržiūros leidimus",
    "Shared with you and the group {group} by {owner}" : "{owner} bendrina su jumis ir grupe {group}",
    "Shared with you by {owner}" : "{owner} bendrina su jumis",
    "Share with users or groups …" : "Bendrinti su naudotojais ar grupėmis …",
    "Share with users, groups or remote users …" : "Bendrinti su naudotojais, grupėmis ar naudotojais kituose serveriuose…",
    "Share link" : "Bendrinimo nuoroda",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Link" : "Nuoroda",
    "Password protect" : "Apsaugoti slaptažodžiu",
    "Password" : "Slaptažodis",
    "Choose a password for the public link" : "Pasirinkite viešos nuorodos slaptažodį",
    "Allow editing" : "Leisti redaguoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "Set expiration date" : "Nustatykite galiojimo laiką",
    "Expiration" : "Galiojimo laikas",
    "Expiration date" : "Galiojimo laikas",
    "This list is maybe truncated - please refine your search term to see more results." : "Šis sąrašas gali būti sugadintas. Patikslinkite ieškomą frazę, jei norite pamatyti daugiau rezultatų.",
    "No users or groups found for {search}" : "Nerasti vartotojai ar grupės pagal raktinį žodį: {search}",
    "No users found for {search}" : "Nerasti naudotojai pagal raktinį žodį: {search}",
    "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
    "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
    "Adding user..." : "Pridedamas naudotojas..",
    "group" : "grupė",
    "remote" : "nutolęs",
    "Resharing is not allowed" : "Dalinimasis iš naujo negalimas",
    "Error while retrieving shares" : "Klaida gaunant bendrinamus duomenis",
    "Unshare" : "Nustoti bendrinti",
    "notify by email" : "pranešti el. paštu",
    "can share" : "gali bendrinti",
    "can edit" : "gali redaguoti",
    "access control" : "prieigos valdymas",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "Password protected" : "Apsaugota slaptažodžiu",
    "Error unsetting expiration date" : "Klaida nuimant galiojimo laiką",
    "Error setting expiration date" : "Klaida nustatant galiojimo laiką",
    "Sending…" : "Siunčiama…",
    "Email sent" : "Laiškas išsiųstas",
    "Warning" : "Įspėjimas",
    "shared by %s" : "pasidalino %s",
    "Direct link" : "Tiesioginė nuoroda",
    "Add to your Nextcloud" : "Pridėti į savo Nextcloud",
    "Media gallery for Nextcloud" : "Medijos galerija, skirta Nextcloud",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Sort by name" : "Rikiuoti pagal pavadinimą",
    "Sort by date" : "Rikiuoti pagal datą",
    "Cancel upload" : "Atsisakyti įkėlimo",
    "Album information" : "Albumo informacija",
    "File list" : "Failų sąrašas",
    "Sorry, this file could not be found." : "Failas nerastas.",
    "Reasons might be:" : "Galimos priežastys:",
    "the wrong file ID was provided" : "pateiktas neteisingas failo ID",
    "the file was removed" : "failas buvo pašalintas",
    "the file is corrupt" : "failas sugadintas",
    "the encryption key is missing" : "nėra šifravimo rakto",
    "Here is the error message returned by the server: " : "Serveris gražino klaidos pranešimą:",
    "For more information, please contact your friendly Nextcloud administrator." : "Išsamesnei informacijai susisiekite su administratoriumi.",
    "Sorry, but the server could not fulfill your request." : "Serveris negali įvykdyti užklausos.",
    "Possible reasons for the problem:" : "Galimos problemos priežastys:",
    "a conflicting app was installed" : "nesuderinama programėlė buvo įdiegta",
    "a required component is missing or was disconnected" : "trūksta reikalingų komponentų arba jie buvo išjungti",
    "the filesystem is not readable" : "failų sistema nenuskaitoma",
    "Sorry, this link doesn't seem to work anymore." : "Nuoroda yra neveiksni.",
    "the item was removed" : "elementas buvo pašalintas",
    "the link has expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more information, please ask the person who has sent you this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "Picture view" : "Paveikslo rodymas",
    "New" : "Naujas",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Pasidalinti su naudotojais kituose serveriuose naudojantis Centralizuoto Serverio ID, pavyzdžiui: username@example.com/cloud",
    "An error occured. Please try again" : "Klaida, prašau bandyti dar kartą.",
    "Sending ..." : "Siunčiama..."
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/lt_LT.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Klaida, skaitant failus iš šio albumo",
    "Aborting preview. Could not find the file" : "Peržiūra nutraukiama. Nepavyko rasti failo",
    "Could not move \"{file}\", target exists" : "Nepavyko perkelti \"{file}\", toks jau yra",
    "Could not move \"{file}\"" : "Nepavyko perkelti \"{file}\"",
    "No compatible server found at {remote}" : "Nerastas joks suderinamas serveris ties {remote}",
    "Invalid server url" : "Neteisingas serverio url adresas",
    "Could not load the description" : "Nepavyko įkelti aprašo",
    "Could not load the description: " : "Nepavyko įkelti aprašo: ",
    "Copyright" : "Autorių teisės",
    "Could not load the copyright notice: " : "Nepavyko įkelti autorių teisių pranešimo: ",
    "Copyright notice" : "Autorių teisių pranešimas",
    "Link to copyright document" : "Nuoroda į autorių teisių dokumentą",
    "This application may not work properly on your browser." : "Ši programa jūsų naršyklėje gali tinkamai neveikti.",
    "For an improved experience, please install one of the following alternatives" : "Geresniam patyrimui, prašome įdiegti vieną iš šių alternatyvų",
    "Your browser is not supported!" : "Jūsų naršyklė nepalaikoma!",
    "please install one of the following alternatives" : "prašome įdiegti vieną iš šių alternatyvų",
    "Album cannot be shown" : "Albumas negali būti parodytas",
    "No media files found" : "Nerasta duomenų peržiūrai",
    "Upload pictures in the Files app to display them here" : "Norėdami matyti paveikslus čia, įkelkite juos į Failų programėlę",
    "Upload new files via drag and drop or by using the [+] button above" : "Įkelkite naujus failus, vilkdami juos čia arba pasinaudoję viršuje esančiu mygtuku [+]",
    "Configuration error" : "Konfigūracijos klaida",
    "Hide Album" : "Slėpti albumą",
    "Could not hide album" : "Nepavyko paslėpti albumo",
    "Error loading slideshow template" : "Klaida, įkeliant skaidrių rodymo šabloną",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Klaida!</strong> Nepavyko sukurti šio failo peržiūros.<br> Prašome pereiti prie kitos skaidrės, kol mes pašalinsime šį paveikslą iš skaidrių rodymo",
    "Next" : "Kitas",
    "Play" : "Groti",
    "Pause" : "Pristabdyti",
    "Previous" : "Ankstesnis",
    "Close" : "Užverti",
    "Download" : "Atsisiųsti",
    "Toggle background" : "Perjungti foną",
    "Delete" : "Ištrinti",
    "Share" : "Bendrinti",
    "Could not create file \"{file}\" because it already exists" : "Nepavyko sukurti failo \"{file}\", kadangi failas tokiu pavadinimu jau yra",
    "Could not create file \"{file}\"" : "Nepavyko sukurti failo \"{file}\"",
    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
    "Upload" : "Įkelti",
    "Error" : "Klaida",
    "Error while sharing" : "Klaida bandant pasidalinti",
    "Error while unsharing" : "Klaida bandant nustoti dalintis",
    "Error while changing permissions" : "Klaida keičiant peržiūros leidimus",
    "Shared with you and the group {group} by {owner}" : "{owner} bendrina su jumis ir grupe {group}",
    "Shared with you by {owner}" : "{owner} bendrina su jumis",
    "Share with users or groups …" : "Dalintis su naudotojais ar grupėmis …",
    "Share with users, groups or remote users …" : "Bendrinti su naudotojais, grupėmis ar naudotojais kituose serveriuose…",
    "Share link" : "Dalinimosi nuoroda",
    "The public link will expire no later than {days} days after it is created" : "Vieša nuoroda galios ne mažiau kaip {days} dienas nuo sukūrimo",
    "Link" : "Nuoroda",
    "Password protect" : "Apsaugoti slaptažodžiu",
    "Password" : "Slaptažodis",
    "Choose a password for the public link" : "Pasirinkite viešos nuorodos slaptažodį",
    "Allow editing" : "Leisti redaguoti",
    "Email link to person" : "Nusiųsti nuorodą paštu",
    "Send" : "Siųsti",
    "Set expiration date" : "Nustatykite galiojimo laiką",
    "Expiration" : "Galiojimo laikas",
    "Expiration date" : "Galiojimo laikas",
    "This list is maybe truncated - please refine your search term to see more results." : "Šis sąrašas gali būti sugadintas. Patikslinkite ieškomą frazę, jei norite pamatyti daugiau rezultatų.",
    "No users or groups found for {search}" : "Nerasti vartotojai ar grupės pagal raktinį žodį: {search}",
    "No users found for {search}" : "Nerasti naudotojai pagal raktinį žodį: {search}",
    "An error occurred (\"{message}\"). Please try again" : "Įvyko klaida (\"{message}\"). Bandykite dar kartą",
    "An error occurred. Please try again" : "Įvyko klaida. Bandykite dar kartą",
    "Adding user..." : "Pridedamas naudotojas..",
    "group" : "grupė",
    "remote" : "nutolęs",
    "Resharing is not allowed" : "Dalinimasis iš naujo negalimas",
    "Error while retrieving shares" : "Klaida gaunant bendrinamus duomenis",
    "Unshare" : "Nustoti bendrinti",
    "notify by email" : "pranešti el. paštu",
    "can share" : "gali bendrinti",
    "can edit" : "gali redaguoti",
    "access control" : "prieigos valdymas",
    "create" : "sukurti",
    "change" : "keisti",
    "delete" : "ištrinti",
    "Password protected" : "Apsaugota slaptažodžiu",
    "Error unsetting expiration date" : "Klaida nuimant galiojimo laiką",
    "Error setting expiration date" : "Klaida nustatant galiojimo laiką",
    "Sending…" : "Siunčiama…",
    "Email sent" : "Laiškas išsiųstas",
    "Warning" : "Įspėjimas",
    "shared by %s" : "pasidalino %s",
    "Direct link" : "Tiesioginė nuoroda",
    "Add to your Nextcloud" : "Pridėti į savo Nextcloud",
    "Media gallery for Nextcloud" : "Medijos galerija, skirta Nextcloud",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Sort by name" : "Rikiuoti pagal pavadinimą",
    "Sort by date" : "Rikiuoti pagal datą",
    "Cancel upload" : "Atšaukti įkėlimą",
    "Album information" : "Albumo informacija",
    "File list" : "Failų sąrašas",
    "Sorry, this file could not be found." : "Failas nerastas.",
    "Reasons might be:" : "Galimos priežastys:",
    "the wrong file ID was provided" : "pateiktas neteisingas failo ID",
    "the file was removed" : "failas buvo pašalintas",
    "the file is corrupt" : "failas sugadintas",
    "the encryption key is missing" : "nėra šifravimo rakto",
    "Here is the error message returned by the server: " : "Serveris gražino klaidos pranešimą:",
    "For more information, please contact your friendly Nextcloud administrator." : "Išsamesnei informacijai susisiekite su administratoriumi.",
    "Sorry, but the server could not fulfill your request." : "Serveris negali įvykdyti užklausos.",
    "Possible reasons for the problem:" : "Galimos problemos priežastys:",
    "a conflicting app was installed" : "nesuderinama programėlė buvo įdiegta",
    "a required component is missing or was disconnected" : "trūksta reikalingų komponentų arba jie buvo išjungti",
    "the filesystem is not readable" : "failų sistema nenuskaitoma",
    "Sorry, this link doesn't seem to work anymore." : "Nuoroda yra neveiksni.",
    "the item was removed" : "elementas buvo pašalintas",
    "the link has expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more information, please ask the person who has sent you this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "Picture view" : "Paveikslėlio rodymas",
    "New" : "Naujas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
